==> treeland_0.5.20.tar.xz: BUILD/translations/treeland.zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>WindowMenu</name>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="29"/>
        <source>Minimize</source>
        <translation>最小化</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="34"/>
        <source>Unmaximize</source>
        <translation>还原</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="34"/>
        <source>Maximize</source>
        <translation>最大化</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="39"/>
        <source>Move</source>
        <translation>移动</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="44"/>
        <source>Resize</source>
        <translation>更改大小</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="50"/>
        <source>Always on Top</source>
        <translation>总在最前</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="56"/>
        <source>Always on Visible Workspace</source>
        <translation>总在可见工作区</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="70"/>
        <source>Move to Left Work Space</source>
        <translation>移至左边的工作区</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="77"/>
        <source>Move to Right Work Space</source>
        <translation>移至右边的工作区</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="83"/>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
</context>
</TS>

==> treeland_0.7.8.tar.xz: BUILD/translations/treeland.zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>WindowMenu</name>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="29"/>
        <source>Minimize</source>
        <translation>最小化</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="34"/>
        <source>Unmaximize</source>
        <translation>还原</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="34"/>
        <source>Maximize</source>
        <translation>最大化</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="39"/>
        <source>Move</source>
        <translation>移动</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="44"/>
        <source>Resize</source>
        <translation>更改大小</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="50"/>
        <source>Always on Top</source>
        <translation>总在最前</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="56"/>
        <source>Always on Visible Workspace</source>
        <translation>总在可见工作区</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="70"/>
        <source>Move to Left Work Space</source>
        <translation>移至左边的工作区</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="77"/>
        <source>Move to Right Work Space</source>
        <translation>移至右边的工作区</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="83"/>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
</context>
</TS>
